Discover Packages
github.com/mocovenwitch/i-failed-a-google-interview
src
fundamentaldatastructures
array
questions
stocksell
package
Version:
v0.0.0-...-b9f9a78
Opens a new window with list of versions in this module.
Published: Jul 12, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func StockSell(price []int ) int
StockSell return max profit
- if using []int as parameter, then we can't pass array to this function
- if using [5]int as parameter, then we have limitation here (type-strong)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.