Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ReverseString1 ¶
func ReverseString1(s []byte)
ReverseString1 use Golang multi-valued assignment what's the strategy underneeth? the memory is observed similar to function above, and slower.
func ReverseString2 ¶
func ReverseString2(s []byte)
ReverseString2 use XOR algorithm The result is the same as the #0 approach. I was expecting it can save some memory...
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.